@@ -3,18 +3,9 @@ import spte
 
 expose = cherrypy.expose
 
-class template:
-    def __init__(self, file='template.spte'):
-        self.file = file
-    def __call__(self, f):
-        def templated(*args):
-            vars = f(*args)
-            return spte.render(self.file, vars)
-        return templated
-
 class Controller:
     @expose
-    @template(file='html.spte')
+    @spte.template(file='html.spte')
     def index(self):
         lista = ['uno', 'dos', 'tres', 'cuatro', 'cinco']
         lista2 = [lista[-i] for i in range(1, len(lista)+1)]
